--
library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.std_logic_arith.all;
use IEEE.std_logic_unsigned.all;

entity P6SYNC is
	port (
		P6_HSYNCN	: in  std_logic;
		P6_VSYNCN	: in  std_logic;
		P6_RGBH		: in  std_logic_vector(3 downto 0);
		CLK50M		: in  std_logic;
		RSTN		: in  std_logic;
		CLKENB		: out std_logic;
		DT_HSYNCN	: out std_logic;
		DT_VSYNCN	: out std_logic;
		DT_RGBH		: out std_logic_vector(3 downto 0);
		MONOUT		: out std_logic_vector(32 downto 0)
	);
end P6SYNC;

architecture RTL of P6SYNC is
	signal p6_hsyncn_f1	: std_logic;
	signal p6_hsyncn_f2	: std_logic;
	signal p6_hsyncn_f3	: std_logic;
	signal p6_hsyncn_f4	: std_logic;
	signal p6_hsyncn_f5	: std_logic;
	signal p6_vsyncn_f1	: std_logic;
	signal p6_vsyncn_f2	: std_logic;
	signal p6_rgbh_f1	: std_logic_vector(3 downto 0);
	signal p6_rgbh_f2	: std_logic_vector(3 downto 0);

	signal hsync		: std_logic;
	signal hsync_f		: std_logic_vector(13 downto 0);

	signal hsynccnt		: std_logic_vector(11 downto 0);

	signal p6cnt456		: std_logic_vector(19 downto 0);
	signal hsynccntnum	: std_logic_vector(19 downto 0);
	signal hsyncclknum	: std_logic_vector(11 downto 0);
	signal hsynccntm456	: std_logic_vector(19 downto 0);

	signal hcnt_int		: std_logic_vector(3 downto 0);
	signal hcnt_dec		: std_logic_vector(7 downto 0);
	signal cnt_int		: std_logic_vector(3 downto 0);
	signal cnt_dec		: std_logic_vector(7 downto 0);
	signal cnt_carry	: std_logic;
	signal dectmp		: std_logic_vector(8 downto 0);

	signal clkenb7m		: std_logic;
	signal dt_hsyncn_i	: std_logic;
	signal dt_vsyncn_i	: std_logic;
	signal dt_rgbh_i	: std_logic_vector(3 downto 0);

	signal testcnt		: std_logic_vector(8 downto 0);

begin

-- input latch
	process (CLK50M,RSTN)
	begin
		if (RSTN = '0') then
			p6_hsyncn_f1 <= '1';
			p6_hsyncn_f2 <= '1';
			p6_hsyncn_f3 <= '1';
			p6_hsyncn_f4 <= '1';
			p6_hsyncn_f5 <= '1';
			p6_vsyncn_f1 <= '1';
			p6_vsyncn_f2 <= '1';
			p6_rgbh_f1   <= "0000";
			p6_rgbh_f2   <= "0000";
		elsif (CLK50M'event and CLK50M = '1') then
			p6_hsyncn_f1 <= P6_HSYNCN;
			p6_hsyncn_f2 <= p6_hsyncn_f1;
			p6_hsyncn_f3 <= p6_hsyncn_f2;
			p6_hsyncn_f4 <= p6_hsyncn_f3;
			p6_hsyncn_f5 <= p6_hsyncn_f4;
			p6_vsyncn_f1 <= P6_VSYNCN;
			p6_vsyncn_f2 <= p6_vsyncn_f1;
			p6_rgbh_f1   <= P6_RGBH;
			p6_rgbh_f2   <= p6_rgbh_f1;
		end if;
	end process;


-- HSYNC pulse generate

	hsync <= '1' when (	p6_hsyncn_f2 = '0' and p6_hsyncn_f3 = '0' and
						p6_hsyncn_f4 = '1' and p6_hsyncn_f5 = '1') else '0';

	process (CLK50M,RSTN)
	begin
		if (RSTN = '0') then
			hsync_f <= (others => '0');
		elsif (CLK50M'event and CLK50M = '1') then
			hsync_f <= hsync_f(12 downto 0) & hsync;
		end if;
	end process;


-- P6 HSYNC counter
	process (CLK50M,RSTN)
	begin
		if (RSTN = '0') then
			hsynccnt    <= (others => '0');
		elsif (CLK50M'event and CLK50M = '1') then
			if (hsync_f(0) = '1') then
				hsynccnt    <= (others => '0');
			else
				hsynccnt    <= hsynccnt + 1;
			end if;
		end if;
	end process;


-- divider (hsynccnt / 0x1C8)
	process (CLK50M,RSTN)
	begin
		if (RSTN = '0') then
			hsynccntnum <= (others => '0');
			hsyncclknum <= (others => '0');
			p6cnt456    <= (others => '0');
		elsif (CLK50M'event and CLK50M = '1') then
			if (hsync_f(0) = '1') then
				hsynccntnum <= (hsynccnt + 1) & X"00";
				hsyncclknum <= (others => '0');
				p6cnt456    <= "11100100" & X"000";	-- 0x1C8
			else
				if (hsynccntm456(19) = '0') then
					hsynccntnum <= hsynccntm456;
					hsyncclknum <= hsyncclknum(10 downto 0) & '1';
					p6cnt456    <= '0' & p6cnt456(19 downto 1);
				else
					hsyncclknum <= hsyncclknum(10 downto 0) & '0';
					p6cnt456    <= '0' & p6cnt456(19 downto 1);
				end if;
			end if;
		end if;
	end process;

	hsynccntm456 <= hsynccntnum - p6cnt456;

	process (CLK50M,RSTN)
	begin
		if (RSTN = '0') then
			hcnt_int <= (others => '0');
			hcnt_dec <= (others => '0');
		elsif (CLK50M'event and CLK50M = '1') then
			if (hsync_f(13) = '1') then
				hcnt_int <= hsyncclknum(11 downto 8);	-- integer
				hcnt_dec <= hsyncclknum( 7 downto 0);	-- decimal
			end if;
		end if;
	end process;


-- 7mclk generate
	process (CLK50M,RSTN)
	begin
		if (RSTN = '0') then
			cnt_int   <= "0001";
			cnt_dec   <= (others => '0');
			cnt_carry <= '0';
		elsif (CLK50M'event and CLK50M = '1') then
			if (hsync_f(0) = '1') then
				cnt_int   <= "0001";
				cnt_dec   <= (others => '0');
				cnt_carry <= '0';
			elsif (cnt_carry = '1') then
				cnt_carry <= '0';
			elsif (cnt_int = hcnt_int) then
				cnt_int   <= "0001";
				cnt_dec   <= dectmp(7 downto 0);
				cnt_carry <= dectmp(8);
			else
				cnt_int <= cnt_int + 1;
			end if;
		end if;
	end process;

	dectmp <= ("0" & cnt_dec) + ("0" & hcnt_dec);


	process (CLK50M,RSTN)
	begin
		if (RSTN = '0') then
			clkenb7m <= '0';
		elsif (CLK50M'event and CLK50M = '1') then
			if (hsync_f(0) = '1') then
				clkenb7m <= '0';
			elsif (cnt_int = 2) then
				clkenb7m <= '1';
			else
				clkenb7m <= '0';
			end if;
		end if;
	end process;



-- data latch
	process (CLK50M,RSTN)
	begin
		if (RSTN = '0') then
			dt_hsyncn_i <= '1';
			dt_vsyncn_i <= '1';
			dt_rgbh_i   <= "0000";
		elsif (CLK50M'event and CLK50M = '1') then
			if (clkenb7m = '1') then
				dt_hsyncn_i <= p6_hsyncn_f2;
				dt_vsyncn_i <= p6_vsyncn_f2;
				dt_rgbh_i   <= p6_rgbh_f2;
			end if;
		end if;
	end process;


-- test counter
	process (CLK50M,RSTN)
	begin
		if (RSTN = '0') then
			testcnt <= (others => '0');
		elsif (CLK50M'event and CLK50M = '1') then
			if (hsync_f(0) = '1') then
				testcnt <= (others => '0');
			elsif (clkenb7m = '1') then
				testcnt <= testcnt + 1;
			end if;
		end if;
	end process;


	MONOUT(32 downto 24) <= testcnt;
	MONOUT(23 downto 12) <= hsynccnt;
	MONOUT(11 downto  8) <= hcnt_int;
	MONOUT( 7 downto  0) <= hcnt_dec;


	CLKENB    <= clkenb7m;

	DT_HSYNCN <= dt_hsyncn_i;
	DT_VSYNCN <= dt_vsyncn_i;
	DT_RGBH   <= dt_rgbh_i;


end RTL;
