-- PC6001 top module
--

library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.std_logic_arith.all;
use IEEE.std_logic_unsigned.all;

entity RGBCONV is
	port (
		DRAM_D			: inout std_logic_vector(15 downto 0);	-- SDRAM data bus
		DRAM_A			: out   std_logic_vector(12 downto 0);	-- SDRAM address bus
		DRAM_CLK		: out   std_logic;						-- SDRAM clock output
		DRAM_CKE		: out   std_logic;						-- SDRAM clock enable
		DRAM_LDQM		: out   std_logic;						-- SDRAM LowerByte Data Mask
		DRAM_UDQM		: out   std_logic;						-- SDRAM UpperByte Data Mask
		DRAM_WE_N		: out   std_logic;						-- SDRAM write Enable
		DRAM_CAS_N		: out   std_logic;						-- SDRAM CAS
		DRAM_RAS_N		: out   std_logic;						-- SDRAM RAS
		DRAM_CS_N		: out   std_logic;						-- SDRAM chip select
		DRAM_BA_1		: out   std_logic;						-- SDRAM Bank #1
		DRAM_BA_0		: out   std_logic;						-- SDRAM Bank #0
		FLASH_D15_AM1	: inout std_logic;						-- FLASH data bus bit15 or adrress-1
		FLASH_D			: inout std_logic_vector(14 downto 0);	-- FLASH data bus
		FLASH_A			: out   std_logic_vector(21 downto 0);	-- FLASH adrress bus
		FLASH_WE_N		: out   std_logic;						-- FLASH write enable
		FLASH_RESET_N	: out   std_logic;						-- FLASH reset
		FLASH_WP_N		: out   std_logic;						-- FLASH write protect
		FLASH_RY		: in    std_logic;						-- FLASH ready
		FLASH_CE_N		: out   std_logic;						-- FLASH chip enable
		FLASH_OE_N		: out   std_logic;						-- FLASH output enable
		FLASH_BYTE_N	: out   std_logic;						-- FLASH byte mode
		VGA_R			: out   std_logic_vector(3 downto 0);	-- VGA red data
		VGA_G			: out   std_logic_vector(3 downto 0);	-- VGA green data
		VGA_B			: out   std_logic_vector(3 downto 0);	-- VGA blue data
		VGA_HS			: out   std_logic;						-- VGA H_SYNC
		VGA_VS			: out   std_logic;						-- VGA V_SYNC
		HEX3_D			: out   std_logic_vector(6 downto 0);	-- 7segment #3
		HEX3_DP			: out   std_logic;						-- 7segment #3 DP
		HEX2_D			: out   std_logic_vector(6 downto 0);	-- 7segment #2
		HEX2_DP			: out   std_logic;						-- 7segment #2 DP
		HEX1_D			: out   std_logic_vector(6 downto 0);	-- 7segment #1
		HEX1_DP			: out   std_logic;						-- 7segment #1 DP
		HEX0_D			: out   std_logic_vector(6 downto 0);	-- 7segment #0
		HEX0_DP			: out   std_logic;						-- 7segment #0 DP
		LEDG			: out   std_logic_vector(9 downto 0);	-- LED
		LCD_D			: inout std_logic_vector(7 downto 0);	-- LCD data bus
		LCD_BLON		: out   std_logic;						-- LCD back light on
		LCD_RS			: out   std_logic;						-- LCD command/data select
		LCD_RW			: out   std_logic;						-- LCD read/write
		LCD_EN			: out   std_logic;						-- LCD enable
		CLK50M1			: in    std_logic;						-- clock 50MHz input #1
		CLK50M0			: in    std_logic;						-- clock 50MHz input #0
		UART_RXD		: in    std_logic;						-- UART Rx
		UART_RTS		: in    std_logic;						-- UART RTS
		UART_TXD		: out   std_logic;						-- UART Tx
		UART_CTS		: out   std_logic;						-- UART CTS
		PS2_KBDAT		: inout std_logic;						-- PS2 keyboard data
		PS2_KBCLK		: inout std_logic;						-- PS2 keyboard clock
		PS2_MSDAT		: inout std_logic;						-- PS2 mouse data
		PS2_MSCLK		: inout std_logic;						-- PS2 mouse clock
		BUTTON			: in    std_logic_vector(2 downto 0);	-- push button
		SW				: in    std_logic_vector(9 downto 0);	-- DIPSW
		GPIO1_D			: inout std_logic_vector(31 downto 0);	-- GPIO #1 data
		GPIO1_CLKIN		: in    std_logic_vector(1 downto 0);	-- GPIO #1 clock input
		GPIO1_CLKOUT	: out   std_logic_vector(1 downto 0);	-- GPIO #1 clock output
		GPIO0_D			: inout std_logic_vector(31 downto 0);	-- GPIO #0 data
		GPIO0_CLKIN		: in    std_logic_vector(1 downto 0);	-- GPIO #0 clock input
		GPIO0_CLKOUT	: out   std_logic_vector(1 downto 0);	-- GPIO #0 clock output
		SD_DAT			: inout std_logic_vector(3 downto 0);	-- SD card data
		SD_CMD			: inout std_logic;						-- SD card command
		SD_CLK			: out   std_logic;						-- SD card clock output
		SD_WP_N			: in    std_logic						-- SD card write protect
	);
end RGBCONV;

architecture RTL of RGBCONV is

	component CLKGEN is
		port (
			CLK50M1		: in  std_logic;	-- clock 50MHz input #1
			CLK50M0		: in  std_logic;	-- clock 50MHz input #0
			MK2MODE		: in  std_logic;
			RSTN		: in  std_logic;
			CLK14MOUT	: out std_logic;
			CLK16MOUT	: out std_logic;
			CLK100MOUT	: out std_logic;
			CLK100M_DI	: out std_logic;
			CLK50MOUT	: out std_logic;
			CLK25MOUT	: out std_logic;
			CLK4MOUT	: out std_logic;
			CLK4MCNTOUT	: out std_logic_vector(1 downto 0);
			CLK1SOUT	: out std_logic;
			LOCK_PLL	: out std_logic
		);
	end component;

	component P6SYNC is
		port (
			P6_HSYNCN	: in  std_logic;
			P6_VSYNCN	: in  std_logic;
			P6_RGBH		: in  std_logic_vector(3 downto 0);
			CLK50M		: in  std_logic;
			RSTN		: in  std_logic;
			CLKENB		: out std_logic;
			DT_HSYNCN	: out std_logic;
			DT_VSYNCN	: out std_logic;
			DT_RGBH		: out std_logic_vector(3 downto 0);
			MONOUT		: out std_logic_vector(32 downto 0)
		);
	end component;

	component VGAOUT is
		port (
			DISPD		: in  std_logic_vector(3 downto 0);
			DISPMD		: in  std_logic_vector(3 downto 0);
			DISPTMG_HS	: in  std_logic;
			DISPTMG_VS	: in  std_logic;
			SC4COLORON	: in  std_logic;
			SC4COLORMD	: in  std_logic_vector(3 downto 0);
			MK2MODE		: in  std_logic;
			LCDMODE		: in  std_logic;
			LCDINITDONE	: in  std_logic;
			DISPMODE	: in  std_logic;
			CLK7MENB	: in  std_logic;
			CLK50M		: in  std_logic;
			CLK25M		: in  std_logic;
			RSTN		: in  std_logic;
			BUSRQMASK	: out std_logic;
			VGA_R		: out std_logic_vector(3 downto 0);
			VGA_G		: out std_logic_vector(3 downto 0);
			VGA_B		: out std_logic_vector(3 downto 0);
			VGA_HS		: out std_logic;
			VGA_VS		: out std_logic;
			LCD_R		: out std_logic_vector(7 downto 0);
			LCD_G		: out std_logic_vector(7 downto 0);
			LCD_B		: out std_logic_vector(7 downto 0);
			LCD_HSN		: out std_logic;
			LCD_VSN		: out std_logic;
			LCD_DEN		: out std_logic;
			LCD_CLK		: out std_logic;
			MONOUT		: out std_logic_vector(18 downto 0)
		);
	end component;

-- clkgen
	signal rstn			: std_logic;
	signal clk14m		: std_logic;
	signal clk16m		: std_logic;
	signal clk25m		: std_logic;
	signal clk50m		: std_logic;
	signal clk100m		: std_logic;
	signal clk100m_di	: std_logic;
	signal clk4m		: std_logic;
	signal clk4mcnt		: std_logic_vector(1 downto 0);
	signal clk1s		: std_logic;
	signal lock_pll		: std_logic;

-- vgaout
	signal dispd		: std_logic_vector(3 downto 0);
	signal dispmd		: std_logic_vector(3 downto 0);
	signal disptmg_hs	: std_logic;
	signal disptmg_vs	: std_logic;
	signal busrqmask	: std_logic;
	signal dispmode		: std_logic;
	signal vga_r_i		: std_logic_vector(3 downto 0);
	signal vga_g_i		: std_logic_vector(3 downto 0);
	signal vga_b_i		: std_logic_vector(3 downto 0);
	signal vga_hs_i		: std_logic;
	signal vga_vs_i		: std_logic;

	signal vga_monout	: std_logic_vector(18 downto 0);

-- for lcd
	signal lcdmode		: std_logic;
	signal lcd_bl		: std_logic;
	signal lcd_cs_i		: std_logic;
	signal lcd_sdi_i	: std_logic;
	signal lcd_scl_i	: std_logic;
	signal lcdinitdone	: std_logic;
	signal lcd_r_i		: std_logic_vector(7 downto 0);
	signal lcd_g_i		: std_logic_vector(7 downto 0);
	signal lcd_b_i		: std_logic_vector(7 downto 0);
	signal lcd_hsn_i	: std_logic;
	signal lcd_vsn_i	: std_logic;
	signal lcd_den_i	: std_logic;
	signal lcd_clk_i	: std_logic;

-- sync
	signal p6_r			: std_logic;
	signal p6_g			: std_logic;
	signal p6_b			: std_logic;
	signal p6_h			: std_logic;
	signal p6_hsyncn	: std_logic;
	signal p6_vsyncn	: std_logic;
	signal p6_rgbh		: std_logic_vector(3 downto 0);

	signal clk7menb		: std_logic;
	signal dt_r			: std_logic;
	signal dt_g			: std_logic;
	signal dt_b			: std_logic;
	signal dt_h			: std_logic;
	signal dt_hsyncn	: std_logic;
	signal dt_hsyncn_f1	: std_logic;
	signal dt_hsyncn_f2	: std_logic;
	signal dt_vsyncn	: std_logic;
	signal dt_vsyncn_f1	: std_logic;
	signal dt_vsyncn_f2	: std_logic;
	signal dt_rgbh		: std_logic_vector(3 downto 0);

	signal p6sync_monout	: std_logic_vector(32 downto 0);

-- prob
	signal dbgtrg		: std_logic_vector(7 downto 0);
	signal gpio1_d_tmp		: std_logic_vector(31 downto 0);
	signal gpio1_clkout_tmp	: std_logic_vector(1 downto 0);

	signal probdat1		: std_logic_vector(7 downto 0);
	signal probdat2		: std_logic_vector(15 downto 0);
	signal probdat3		: std_logic_vector(7 downto 0);

	signal sw86			: std_logic_vector(2 downto 0);
	signal dec_firmad	: std_logic;
	signal dec_subst	: std_logic;

begin

-- clock generate
	rstn <= BUTTON(2);

	U_CLKGEN : CLKGEN
	port map (
		CLK50M1		=> CLK50M1,
		CLK50M0		=> CLK50M0,
		MK2MODE		=> '1',
		RSTN		=> rstn,
		CLK14MOUT	=> clk14m,
		CLK16MOUT	=> clk16m,
		CLK100MOUT	=> clk100m,
		CLK100M_DI	=> clk100m_di,
		CLK50MOUT	=> clk50m,
		CLK25MOUT	=> clk25m,
		CLK4MOUT	=> clk4m,
		CLK4MCNTOUT	=> clk4mcnt,
		CLK1SOUT	=> clk1s,
		LOCK_PLL	=> lock_pll
	);

	U_P6SYNC : P6SYNC
	port map (
		P6_HSYNCN	=> p6_hsyncn,
		P6_VSYNCN	=> p6_vsyncn,
		P6_RGBH		=> p6_rgbh,
		CLK50M		=> clk50m,
		RSTN		=> rstn,
		CLKENB		=> clk7menb,
		DT_HSYNCN	=> dt_hsyncn,
		DT_VSYNCN	=> dt_vsyncn,
		DT_RGBH		=> dt_rgbh,
		MONOUT		=> p6sync_monout
	);

	p6_rgbh <= p6_r & p6_g & p6_b & p6_h;

	dt_r <= dt_rgbh(3);
	dt_g <= dt_rgbh(2);
	dt_b <= dt_rgbh(1);
	dt_h <= dt_rgbh(0);

	dispd      <= dt_h & dt_g & dt_r & dt_b;
	dispmd     <= "0000";

	process (rstn,clk50m)
	begin
		if (rstn = '0') then
			dt_hsyncn_f1 <= '1';
			dt_hsyncn_f2 <= '1';
			dt_vsyncn_f1 <= '1';
			dt_vsyncn_f2 <= '1';
		elsif (clk50m'event and clk50m = '1') then
			if (clk7menb = '1') then
				dt_hsyncn_f1 <= dt_hsyncn;
				dt_hsyncn_f2 <= dt_hsyncn_f1;
				if (disptmg_hs = '1') then
					dt_vsyncn_f1 <= dt_vsyncn;
					dt_vsyncn_f2 <= dt_vsyncn_f1;
				end if;
			end if;
		end if;
	end process;

	disptmg_hs <= '1' when (dt_hsyncn_f1 = '0' and dt_hsyncn_f2 = '1') else '0';
	disptmg_vs <= '1' when (dt_vsyncn_f1 = '0' and dt_vsyncn_f2 = '1') else '0';

-- VGA output
	U_VGAOUT : VGAOUT
	port map (
		DISPD		=> dispd,
		DISPMD		=> dispmd,
		DISPTMG_HS	=> disptmg_hs,
		DISPTMG_VS	=> disptmg_vs,
		SC4COLORON	=> SW(1),
		SC4COLORMD	=> SW(5 downto 2),
		MK2MODE		=> '1',
		LCDMODE		=> lcdmode,
		LCDINITDONE	=> lcdinitdone,
		DISPMODE	=> '0',
		CLK7MENB	=> clk7menb,
		CLK50M		=> clk50m,
		CLK25M		=> clk25m,
		RSTN		=> rstn,
		BUSRQMASK	=> open,
		VGA_R		=> vga_r_i,
		VGA_G		=> vga_g_i,
		VGA_B		=> vga_b_i,
		VGA_HS		=> vga_hs_i,
		VGA_VS		=> vga_vs_i,
		LCD_R		=> lcd_r_i,
		LCD_G		=> lcd_g_i,
		LCD_B		=> lcd_b_i,
		LCD_HSN		=> lcd_hsn_i,
		LCD_VSN		=> lcd_vsn_i,
		LCD_DEN		=> lcd_den_i,
		LCD_CLK		=> lcd_clk_i,
		MONOUT		=> vga_monout
	);


	VGA_R  <= vga_r_i;
	VGA_G  <= vga_g_i;
	VGA_B  <= vga_b_i;
	VGA_HS <= vga_hs_i;
	VGA_VS <= vga_vs_i;

	lcdinitdone <= '1';	-- dummy

	lcd_cs_i  <= '0';	-- dummy
	lcd_scl_i <= '0';	-- dummy
	lcd_sdi_i <= '0';	-- dummy


	lcdmode <= SW(0);

	lcd_bl <= lcdmode;

	gpio1_d_tmp(0)		<= 'Z';				-- N.C.
	gpio1_d_tmp(1)		<= 'Z';				-- N.C.
	gpio1_d_tmp(2)		<= lcd_bl;			-- N.C.
	gpio1_d_tmp(3)		<= rstn;			-- RESET
	gpio1_d_tmp(4)		<= lcd_cs_i;		-- CS
	gpio1_d_tmp(5)		<= lcd_scl_i;		-- SCL
	gpio1_d_tmp(6)		<= lcd_sdi_i;		-- SDI
	gpio1_d_tmp(7)		<= lcd_b_i(0);		-- B(0)
	gpio1_d_tmp(8)		<= lcd_b_i(1);		-- B(1)
	gpio1_d_tmp(9)		<= lcd_b_i(2);		-- B(2)
	gpio1_d_tmp(10)		<= lcd_b_i(3);		-- B(3)
	gpio1_d_tmp(11)		<= lcd_b_i(4);		-- B(4)
	gpio1_d_tmp(12)		<= lcd_b_i(5);		-- B(5)
	gpio1_d_tmp(13)		<= lcd_b_i(6);		-- B(6)
	gpio1_clkout_tmp(0)	<= lcd_b_i(7);		-- B(7)
	gpio1_d_tmp(14)		<= lcd_g_i(0);		-- G(0)
	gpio1_clkout_tmp(1)	<= lcd_g_i(1);		-- G(1)
	gpio1_d_tmp(15)		<= lcd_g_i(2);		-- G(2)
	gpio1_d_tmp(16)		<= lcd_g_i(3);		-- G(3)
	gpio1_d_tmp(17)		<= lcd_g_i(4);		-- G(4)
	gpio1_d_tmp(18)		<= lcd_g_i(5);		-- G(5)
	gpio1_d_tmp(19)		<= lcd_g_i(6);		-- G(6)
	gpio1_d_tmp(20)		<= lcd_g_i(7);		-- G(7)
	gpio1_d_tmp(21)		<= lcd_r_i(0);		-- R(0)
	gpio1_d_tmp(22)		<= lcd_r_i(1);		-- R(1)
	gpio1_d_tmp(23)		<= lcd_r_i(2);		-- R(2)
	gpio1_d_tmp(24)		<= lcd_r_i(3);		-- R(3)
	gpio1_d_tmp(25)		<= lcd_r_i(4);		-- R(4)
	gpio1_d_tmp(26)		<= lcd_r_i(5);		-- R(5)
	gpio1_d_tmp(27)		<= lcd_r_i(6);		-- R(6)
	gpio1_d_tmp(28)		<= lcd_r_i(7);		-- R(7)
	gpio1_d_tmp(29)		<= lcd_hsn_i;		-- HSYNC
	gpio1_d_tmp(30)		<= lcd_vsn_i;		-- VSYNC
	gpio1_d_tmp(31)		<= lcd_clk_i;		-- DOTCLK


	GPIO0_D(31 downto 12) <= (others => 'Z');
	GPIO0_D( 7 downto  4) <= (others => 'Z');
	GPIO0_D( 2 downto  0) <= (others => 'Z');


	p6_h      <= GPIO0_D(11);
	p6_b      <= GPIO0_D(10);
	p6_g      <= GPIO0_D(9);
	p6_r      <= GPIO0_D(8);
	p6_vsyncn <= GPIO0_D(4);
	p6_hsyncn <= GPIO0_D(3);


	GPIO0_CLKOUT(1 downto 0)	<= (others => 'Z');

	LEDG(0) <= '0';
	LEDG(1) <= '0';
	LEDG(2) <= '0';
	LEDG(3) <= '0';
	LEDG(4) <= '0';
	LEDG(5) <= '0';
	LEDG(6) <= '0';
	LEDG(7) <= '0';
	LEDG(8) <= '0';
	LEDG(9) <= '0';

-- probe output

	probdat1 <=	clk50m & clk7menb & p6_rgbh & p6_vsyncn & p6_hsyncn when (SW(8) = '1') else
				clk50m & clk7menb & dt_rgbh & dt_vsyncn & dt_hsyncn;
	probdat2 <= vga_monout(15 downto 0);
--				"000" & p6sync_monout(32 downto 24) & p6sync_monout(11 downto 8) when (SW(7) = '1') else
--				p6sync_monout(23 downto 8);
	probdat3 <= "00000" & vga_monout(18 downto 16);
--				p6sync_monout(7 downto 0);

	gpio1_d_tmp(13)		<= lcd_b_i(6);		-- B(6)
	gpio1_clkout_tmp(0)	<= lcd_b_i(7);		-- B(7)

	GPIO1_D(0)		<= gpio1_d_tmp(0)		;
	GPIO1_D(1)		<= gpio1_d_tmp(1)		;

	GPIO1_D(3)		<= gpio1_d_tmp(3)      when (SW(9) = '0') else probdat1(0)	;	-- PROBE #00(trigger)
	GPIO1_D(2)		<= gpio1_d_tmp(2)      when (SW(9) = '0') else probdat1(1)	;	-- PROBE #01(trigger)
	GPIO1_D(5)		<= gpio1_d_tmp(5)      when (SW(9) = '0') else probdat1(2)	;	-- PROBE #02(trigger)
	GPIO1_D(4)		<= gpio1_d_tmp(4)      when (SW(9) = '0') else probdat1(3)	;	-- PROBE #03(trigger)
	GPIO1_D(7)		<= gpio1_d_tmp(7)      when (SW(9) = '0') else probdat1(4)	;	-- PROBE #04(trigger)
	GPIO1_D(6)		<= gpio1_d_tmp(6)      when (SW(9) = '0') else probdat1(5)	;	-- PROBE #05(trigger)
	GPIO1_D(9)		<= gpio1_d_tmp(9)      when (SW(9) = '0') else probdat1(6)	;	-- PROBE #06(trigger)
	GPIO1_D(8)		<= gpio1_d_tmp(8)      when (SW(9) = '0') else probdat1(7)	;	-- PROBE #07(trigger)
	GPIO1_D(11)		<= gpio1_d_tmp(11)     when (SW(9) = '0') else probdat2(0)	;	-- PROBE #08(trigger)
	GPIO1_D(10)		<= gpio1_d_tmp(10)     when (SW(9) = '0') else probdat2(1)	;	-- PROBE #09(trigger)
	GPIO1_D(13)		<= gpio1_d_tmp(13)     when (SW(9) = '0') else probdat2(2)	;	-- PROBE #10(trigger)
	GPIO1_D(12)		<= gpio1_d_tmp(12)     when (SW(9) = '0') else probdat2(3)	;	-- PROBE #11(trigger)
	GPIO1_D(14)		<= gpio1_d_tmp(14)     when (SW(9) = '0') else probdat2(4)	;	-- PROBE #12(trigger)
	GPIO1_CLKOUT(0)	<= gpio1_clkout_tmp(0) when (SW(9) = '0') else probdat2(5)	;	-- PROBE #13(trigger)
	GPIO1_D(15)		<= gpio1_d_tmp(15)     when (SW(9) = '0') else probdat2(6)	;	-- PROBE #14(trigger)
	GPIO1_CLKOUT(1)	<= gpio1_clkout_tmp(1) when (SW(9) = '0') else probdat2(7)	;	-- PROBE #15
	GPIO1_D(17)		<= gpio1_d_tmp(17)     when (SW(9) = '0') else probdat2(8)	;	-- PROBE #16
	GPIO1_D(16)		<= gpio1_d_tmp(16)     when (SW(9) = '0') else probdat2(9)	;	-- PROBE #17
	GPIO1_D(19)		<= gpio1_d_tmp(19)     when (SW(9) = '0') else probdat2(10)	;	-- PROBE #18
	GPIO1_D(18)		<= gpio1_d_tmp(18)     when (SW(9) = '0') else probdat2(11)	;	-- PROBE #19
	GPIO1_D(21)		<= gpio1_d_tmp(21)     when (SW(9) = '0') else probdat2(12)	;	-- PROBE #20
	GPIO1_D(20)		<= gpio1_d_tmp(20)     when (SW(9) = '0') else probdat2(13)	;	-- PROBE #21
	GPIO1_D(23)		<= gpio1_d_tmp(23)     when (SW(9) = '0') else probdat2(14)	;	-- PROBE #22
	GPIO1_D(22)		<= gpio1_d_tmp(22)     when (SW(9) = '0') else probdat2(15)	;	-- PROBE #23
	GPIO1_D(25)		<= gpio1_d_tmp(25)     when (SW(9) = '0') else probdat3(0)	;	-- PROBE #24
	GPIO1_D(24)		<= gpio1_d_tmp(24)     when (SW(9) = '0') else probdat3(1)	;	-- PROBE #25
	GPIO1_D(27)		<= gpio1_d_tmp(27)     when (SW(9) = '0') else probdat3(2)	;	-- PROBE #26
	GPIO1_D(26)		<= gpio1_d_tmp(26)     when (SW(9) = '0') else probdat3(3)	;	-- PROBE #27
	GPIO1_D(29)		<= gpio1_d_tmp(29)     when (SW(9) = '0') else probdat3(4)	;	-- PROBE #28
	GPIO1_D(28)		<= gpio1_d_tmp(28)     when (SW(9) = '0') else probdat3(5)	;	-- PROBE #29
	GPIO1_D(31)		<= gpio1_d_tmp(31)     when (SW(9) = '0') else probdat3(6)	;	-- PROBE #30
	GPIO1_D(30)		<= gpio1_d_tmp(30)     when (SW(9) = '0') else probdat3(7)	;	-- PROBE #31

-- unused pin
	HEX3_D			<= (others => '1');
	HEX3_DP			<= '1';
	HEX2_D			<= (others => '1');
	HEX2_DP			<= '1';
	HEX1_D			<= (others => '1');
	HEX1_DP			<= '1';
	HEX0_D			<= (others => '1');
	HEX0_DP			<= '1';
	UART_TXD		<= '0';
	UART_CTS		<= '0';
	DRAM_A			<= (others => '0');
	DRAM_LDQM		<= '0';
	DRAM_UDQM		<= '0';
	DRAM_WE_N		<= '1';
	DRAM_CAS_N		<= '1';
	DRAM_RAS_N		<= '1';
	DRAM_CS_N		<= '1';
	DRAM_BA_0		<= '0';
	DRAM_BA_1		<= '0';
	DRAM_CLK		<= '0';
	DRAM_CKE		<= '0';
	FLASH_A			<= (others => '0');
	FLASH_WE_N		<= '1';
	FLASH_RESET_N	<= '0';
	FLASH_OE_N		<= '1';
	FLASH_CE_N		<= '1';
	FLASH_WP_N		<= '1';
	FLASH_BYTE_N	<= '1';
	LCD_BLON		<= '0';
	LCD_RW			<= '0';
	LCD_EN			<= '0';
	LCD_RS			<= '0';
	SD_CLK			<= '0';
	GPIO0_CLKOUT	<= (others => '0');

	DRAM_D			<= (others => 'Z');
	FLASH_D15_AM1	<= 'Z';
	FLASH_D			<= (others => 'Z');
	LCD_D			<= (others => 'Z');
	PS2_KBDAT		<= 'Z';
	PS2_KBCLK		<= 'Z';
	PS2_MSDAT		<= 'Z';
	PS2_MSCLK		<= 'Z';
	SD_DAT			<= (others => 'Z');
	SD_CMD			<= 'Z';

end RTL;
